from pybrary.func import todo


class Module:
    def __init__(self, distro):
        self.distro = distro

    def deploy(self, target, **kw):
        todo(self)
